/**
 * Copyright (c) 2014,2018 Contributors to the Eclipse Foundation
 * 
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 */
package org.eclipse.smarthome.model.validation;

import org.eclipse.smarthome.core.types.util.UnitUtils;
import org.eclipse.smarthome.model.items.ItemsPackage;
import org.eclipse.smarthome.model.items.ModelItem;
import org.eclipse.smarthome.model.validation.AbstractItemsValidator;
import org.eclipse.xtext.validation.Check;
import org.eclipse.xtext.xbase.lib.Exceptions;

/**
 * Custom validation rules.
 * 
 * see http://www.eclipse.org/Xtext/documentation.html#validation
 */
@SuppressWarnings("all")
public class ItemsValidator extends AbstractItemsValidator {
  @Check
  public void checkItemName(final ModelItem item) {
    if (((item == null) || (item.getName() == null))) {
      return;
    }
    boolean _contains = item.getName().contains("-");
    if (_contains) {
      this.error("Item name must not contain dashes.", ItemsPackage.Literals.MODEL_ITEM__NAME);
    }
  }
  
  @Check
  public void checkDiemension(final ModelItem item) {
    if (((item == null) || (item.getType() == null))) {
      return;
    }
    boolean _startsWith = item.getType().startsWith("Number:");
    if (_startsWith) {
      String _type = item.getType();
      int _indexOf = item.getType().indexOf(":");
      int _plus = (_indexOf + 1);
      String dimension = _type.substring(_plus);
      try {
        UnitUtils.parseDimension(dimension);
      } catch (final Throwable _t) {
        if (_t instanceof IllegalArgumentException) {
          this.warning((("\'" + dimension) + "\' is not a valid dimension."), ItemsPackage.Literals.MODEL_ITEM__TYPE);
        } else {
          throw Exceptions.sneakyThrow(_t);
        }
      }
    }
  }
}
